<?php
/**
 * @file
 *
 * Displays a single Drupal page.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $css: An array of CSS files for the current page.
 * - $directory: The directory the theme is located in, e.g. themes/garland or
 *   themes/garland/minelli.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Page metadata:
 * - $language: (object) The language the site is being displayed in.
 *   $language->language contains its textual representation.
 *   $language->dir contains the language direction. It will either be 'ltr' or
 *   'rtl'.
 * - $head_title: A modified version of the page title, for use in the TITLE
 *   element.
 * - $head: Markup for the HEAD element (including meta tags, keyword tags, and
 *   so on).
 * - $styles: Style tags necessary to import all CSS files for the page.
 * - $scripts: Script tags necessary to load the JavaScript files and settings
 *   for the page.
 * - $body_classes: A set of CSS classes for the BODY tag. This contains flags
 *   indicating the current layout (multiple columns, single column), the
 *   current path, whether the user is logged in, and so on.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled in
 *   theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 * - $mission: The text of the site mission, empty when display has been
 *   disabled in theme settings.
 *
 * Navigation:
 * - $search_box: HTML to display the search box, empty if search has been
 *   disabled.
 * - $primary_links (array): An array containing primary navigation links for
 *   the site, if they have been configured.
 * - $secondary_links (array): An array containing secondary navigation links
 *   for the site, if they have been configured.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $left: The HTML for the left sidebar.
 * - $breadcrumb: The breadcrumb trail for the current page.
 * - $title: The page title, for use in the actual HTML content.
 * - $help: Dynamic help text, mostly for admin pages.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs: Tabs linking to any sub-pages beneath the current page (e.g., the
 *   view and edit tabs when displaying a node).
 * - $content: The main content of the current Drupal page.
 * - $right: The HTML for the right sidebar.
 * - $node: The node object, if there is an automatically-loaded node associated
 *   with the page, and the node ID is the second argument in the page's path
 *   (e.g. node/12345 and node/12345/revisions, but not comment/reply/12345).
 *
 * Footer/closing data:
 * - $feed_icons: A string of all feed icons for the current page.
 * - $footer_message: The footer message as defined in the admin settings.
 * - $footer : The footer region.
 * - $closure: Final closing markup from any modules that have altered the page.
 *   This variable should always be output last, after all other dynamic
 *   content.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 */
?>
<?php
/**
 * Additional variables:
 * - $addthis_xmlns: AddThis XMLNS namespace.
 * - $facebook_xmlns: Facebook XMLNS namespace.
 * - $base_theme_path: The directory the base theme (p6_base) is located in.
 * - $active_theme_path: The directory of the active theme.
 * - $body_id: The unique page id based on the path.
 * - $ie6warning: Old browser warning with links to download a newer version.
 * - $no_javascript: JavaScript is either disabled or not supported.
 *
 * @see p6_base_preprocess_page()
 */
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<!--[if lt IE 7 ]> <html xmlns="http://www.w3.org/1999/xhtml" <?php print $addthis_xmlns; ?> <?php print $facebook_xmlns; ?> lang="<?php print $language->language; ?>" xml:lang="<?php print $language->language; ?>" class="no-js lt-ie9 lt-ie8 lt-ie7"> <![endif]-->
<!--[if IE 7 ]>    <html xmlns="http://www.w3.org/1999/xhtml" <?php print $addthis_xmlns; ?> <?php print $facebook_xmlns; ?> lang="<?php print $language->language; ?>" xml:lang="<?php print $language->language; ?>" class="no-js lt-ie9 lt-ie8"> <![endif]-->
<!--[if IE 8 ]>    <html xmlns="http://www.w3.org/1999/xhtml" <?php print $addthis_xmlns; ?> <?php print $facebook_xmlns; ?> lang="<?php print $language->language; ?>" xml:lang="<?php print $language->language; ?>" class="no-js lt-ie9"> <![endif]-->
<!--[if gt IE 8]><!--> <html xmlns="http://www.w3.org/1999/xhtml" <?php print $addthis_xmlns; ?> <?php print $facebook_xmlns; ?> lang="<?php print $language->language; ?>" xml:lang="<?php print $language->language; ?>" class="no-js"> <!--<![endif]-->
<head>
<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1" />
<?php print $head; ?>
<title><?php print $head_title; ?></title>
<meta name="viewport" content="width=device-width" />
<link rel="apple-touch-icon" href="<?php print $base_path . $active_theme_path; ?>/ico/apple-touch-icon.png" />
<?php print $styles; ?>
<?php /* All JavaScript at the bottom, except for Modernizr which enables HTML5 elements & feature detects */ ?>

</head>
<body id="<?php print $body_id; ?>" class="<?php print $body_classes; ?>">

<a name="top" id="top" class="visuallyhidden"></a>

<div id="skip-link">
  <a tabindex="1" class="visuallyhidden focusable" href="#ui-header"><?php print t('Skip messages'); ?></a>
  <a tabindex="2" class="visuallyhidden focusable" href="#ui-content"><?php print t('Skip to main content'); ?></a>
</div>

<?php print theme('p6', $ie6warning, 'ui-ie6', 'ui-page-width', '<!--[if lt IE 7]>', '<![endif]-->'); ?>

<?php // print theme('p6', $no_javascript, 'ui-nojs', 'ui-page-width'); ?>

<?php print theme('p6', $messages . $help, 'ui-info', 'ui-page-width'); ?>

<div id="ui">
<div id="ui-header">
  <div id="ui-header-top">
    <div class="ui-inner ui-page-width clearfix">
      <div id="ui-site-name" class="clearfix">
        <h1><a tabindex="0" href="<?php print check_url($front_page); ?>" title="<?php print check_plain($site_name); ?>">
        <?php if ($logo): ?>
        <img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>" />
        <?php endif; ?>
        <span><?php print $site_name; ?></span>
        <?php if (!empty($site_slogan)): ?><small><?php print $site_slogan; ?></small><?php endif; ?>
        </a></h1>
      </div>

      <?php if (!empty($secondary_links)): ?>
      <?php print theme('links', $secondary_links, array('id' => 'ui-meta-nav', 'class' => 'clearfix')); ?>
      <?php endif; ?>

      <?php // if (!empty($search_box)): print $search_box; endif; ?>

      <?php print $header; ?>
    </div>
  </div><!-- /id="ui-header-top" -->

  <?php print theme('p6', $header_bottom, 'ui-header-bottom', 'ui-page-width'); ?>

</div><!-- / id="ui-header" -->
<div id="ui-main"><div class="ui-inner ui-page-width clearfix">

<?php print theme('p6', $page_hero, 'ui-hero'); ?>

<div id="ui-content-wrapper">
<div id="ui-content"><div class="ui-inner clearfix">
  <?php // print theme('p6', $breadcrumb, 'ui-breadcrumb'); ?>

  <?php print theme('p6', $content_top, 'ui-content-top'); ?>

  <?php print theme('p6', $tabs, 'ui-tabs'); ?>

  <?php if (!empty($title)): ?>
  <h1 class="ui-title" id="ui-page-title"><?php print $title; ?></h1>
  <?php endif; ?>

  <?php print $content; ?>

  <?php print theme('p6', $content_bottom, 'ui-content-bottom'); ?>

</div></div>
</div><!-- /id="ui-content-wrapper" -->

<?php print theme('p6', $sidebar_first, 'ui-sidebar-first'); ?>

<?php print theme('p6', $sidebar_last, 'ui-sidebar-last'); ?>

</div></div><!-- /id="ui-main" -->

<?php print theme('p6', $footer, 'ui-footer', 'ui-page-width'); ?>

<?php print theme('p6', $footer_bottom, 'ui-footer-bottom', 'ui-page-width'); ?>

</div><!-- /id="ui" -->

<?php if (!module_exists('p6_helper')): print $feed_icons; endif; ?>

<?php // print $scripts; ?>

<?php print $closure; ?>
</body>
</html>
